@@ -551,6 +551,31 @@ class Residue(Entity):
         if type(bonded_force_entity).name not in self.bonded_forces.keys():
             self.bonded_forces[type(bonded_force_entity).name] = []
         self.bonded_forces[type(bonded_force_entity).name].append(bonded_force_entity)
+    
+    def Add_Missing_Atoms(self):
+        from random import uniform
+        t = set([atom.name for atom in self.atoms])
+        uncertified = set([atom.name for atom in self.type.atoms])
+        for atom in self.type.atoms:
+            if atom.name in t:
+                uncertified.remove(atom.name)
+
+        while uncertified:
+          movedlist = []
+          for atom_name in uncertified:
+            temp_atom = getattr(self.type, atom_name)
+            for connected_atom in self.type.connectivity[temp_atom]:
+                if connected_atom.name in t:
+                    fact_connected_atom = self._name2atom[connected_atom.name]
+                    _x = temp_atom.x - connected_atom.x + fact_connected_atom.x
+                    _y = temp_atom.y - connected_atom.y + fact_connected_atom.y
+                    _z = temp_atom.z - connected_atom.z + fact_connected_atom.z
+                    t.add(atom_name)
+                    movedlist.append(atom_name)
+                    self.Add_Atom(atom_name, x = _x, y = _y, z = _z)
+          for atom_name in movedlist:
+              uncertified.remove(atom_name)
+        
 
     def deepcopy(self, forcopy=None):
         new_residue = Residue(self.type)
@@ -645,6 +670,10 @@ class Molecule:
     def Add_Residue_Link(self, atom1, atom2):
         self.builded = False
         self.residue_links.append(ResidueLink(atom1, atom2))
+    
+    def Add_Missing_Atoms(self):
+        for residue in self.residues:
+            residue.Add_Missing_Atoms()
 
     def deepcopy(self):
         new_molecule = Molecule(self.name)
