@@ -2,7 +2,6 @@ from . import *
 import sys
 
 atoms, bonds, angles, propers, impropers, LJs = LOAD.parmdat(os.path.join(AMBER_DATA_DIR, "parm10.dat"))
-
 AtomType.New_From_String(atoms)
 BOND.BondType.New_From_String(bonds)
 ANGLE.AngleType.New_From_String(angles)
@@ -73,7 +72,7 @@ GlobalSetting.HISMap["HIS"].update({"HIS": {"HID":"HID", "HIE":"HIE", "HIP":"HIP
 
 ResidueType.types["CYX"].connect_atoms["ssbond"] = "SG"
 
-print("""Reference for ff14SB.py:
+print("""Reference for ff14SB:
   James A. Maier, Carmenza Martinez, Koushik Kasavajhala, Lauren Wickstrom, Kevin E. Hauser, and Carlos Simmerling
     ff14SB: Improving the accuracy of protein side chain and backbone parameters from ff99SB
     Journal of Chemical Theory and Computation 2015 11 (8), 3696-3713
